@@ -48,8 +48,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -65,10 +65,10 @@ class DataNullDataSource(
     def __init__(
         self,
         scope: constructs.Construct,
-        id: str,
+        id: builtins.str,
         *,
-        has_computed_default: typing.Optional[str] = None,
-        inputs: typing.Optional[typing.Mapping[str, str]] = None,
+        has_computed_default: typing.Optional[builtins.str] = None,
+        inputs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         count: typing.Optional[jsii.Number] = None,
         depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
         lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
@@ -96,46 +96,49 @@ class DataNullDataSource(
         jsii.create(DataNullDataSource, self, [scope, id, config])
 
     @jsii.member(jsii_name="outputs")
-    def outputs(self, key: str) -> str:
+    def outputs(self, key: builtins.str) -> builtins.str:
         """
         :param key: -
         """
         return jsii.invoke(self, "outputs", [key])
 
     @jsii.member(jsii_name="synthesizeAttributes")
-    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
+    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.invoke(self, "synthesizeAttributes", [])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="random")
-    def random(self) -> str:
+    def random(self) -> builtins.str:
         return jsii.get(self, "random")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="hasComputedDefault")
-    def has_computed_default(self) -> typing.Optional[str]:
+    def has_computed_default(self) -> typing.Optional[builtins.str]:
         return jsii.get(self, "hasComputedDefault")
 
-    @has_computed_default.setter
-    def has_computed_default(self, value: typing.Optional[str]) -> None:
+    @has_computed_default.setter # type: ignore
+    def has_computed_default(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "hasComputedDefault", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="id")
-    def id(self) -> typing.Optional[str]:
+    def id(self) -> typing.Optional[builtins.str]:
         return jsii.get(self, "id")
 
-    @id.setter
-    def id(self, value: typing.Optional[str]) -> None:
+    @id.setter # type: ignore
+    def id(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "id", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="inputs")
-    def inputs(self) -> typing.Optional[typing.Mapping[str, str]]:
+    def inputs(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         return jsii.get(self, "inputs")
 
-    @inputs.setter
-    def inputs(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
+    @inputs.setter # type: ignore
+    def inputs(
+        self,
+        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
+    ) -> None:
         jsii.set(self, "inputs", value)
 
 
@@ -159,8 +162,8 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
         depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
         lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
         provider: typing.Optional[cdktf.TerraformProvider] = None,
-        has_computed_default: typing.Optional[str] = None,
-        inputs: typing.Optional[typing.Mapping[str, str]] = None,
+        has_computed_default: typing.Optional[builtins.str] = None,
+        inputs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
     ) -> None:
         """
         :param count: 
@@ -172,7 +175,7 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
         """
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if count is not None:
             self._values["count"] = count
         if depends_on is not None:
@@ -192,7 +195,8 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
         stability
         :stability: experimental
         """
-        return self._values.get("count")
+        result = self._values.get("count")
+        return result
 
     @builtins.property
     def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
@@ -200,7 +204,8 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
         stability
         :stability: experimental
         """
-        return self._values.get("depends_on")
+        result = self._values.get("depends_on")
+        return result
 
     @builtins.property
     def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
@@ -208,7 +213,8 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
         stability
         :stability: experimental
         """
-        return self._values.get("lifecycle")
+        result = self._values.get("lifecycle")
+        return result
 
     @builtins.property
     def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
@@ -216,20 +222,23 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
         stability
         :stability: experimental
         """
-        return self._values.get("provider")
+        result = self._values.get("provider")
+        return result
 
     @builtins.property
-    def has_computed_default(self) -> typing.Optional[str]:
-        return self._values.get("has_computed_default")
+    def has_computed_default(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("has_computed_default")
+        return result
 
     @builtins.property
-    def inputs(self) -> typing.Optional[typing.Mapping[str, str]]:
-        return self._values.get("inputs")
+    def inputs(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
+        result = self._values.get("inputs")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -246,9 +255,9 @@ class NullProvider(
     def __init__(
         self,
         scope: constructs.Construct,
-        id: str,
+        id: builtins.str,
         *,
-        alias: typing.Optional[str] = None,
+        alias: typing.Optional[builtins.str] = None,
     ) -> None:
         """
         :param scope: -
@@ -260,16 +269,16 @@ class NullProvider(
         jsii.create(NullProvider, self, [scope, id, config])
 
     @jsii.member(jsii_name="synthesizeAttributes")
-    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
+    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.invoke(self, "synthesizeAttributes", [])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="alias")
-    def alias(self) -> typing.Optional[str]:
+    def alias(self) -> typing.Optional[builtins.str]:
         return jsii.get(self, "alias")
 
-    @alias.setter
-    def alias(self, value: typing.Optional[str]) -> None:
+    @alias.setter # type: ignore
+    def alias(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "alias", value)
 
 
@@ -279,23 +288,24 @@ class NullProvider(
     name_mapping={"alias": "alias"},
 )
 class NullProviderConfig:
-    def __init__(self, *, alias: typing.Optional[str] = None) -> None:
+    def __init__(self, *, alias: typing.Optional[builtins.str] = None) -> None:
         """
         :param alias: Alias name.
         """
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if alias is not None:
             self._values["alias"] = alias
 
     @builtins.property
-    def alias(self) -> typing.Optional[str]:
+    def alias(self) -> typing.Optional[builtins.str]:
         """Alias name."""
-        return self._values.get("alias")
+        result = self._values.get("alias")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
@@ -312,9 +322,9 @@ class Resource(
     def __init__(
         self,
         scope: constructs.Construct,
-        id: str,
+        id: builtins.str,
         *,
-        triggers: typing.Optional[typing.Mapping[str, str]] = None,
+        triggers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         count: typing.Optional[jsii.Number] = None,
         depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
         lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
@@ -340,25 +350,28 @@ class Resource(
         jsii.create(Resource, self, [scope, id, config])
 
     @jsii.member(jsii_name="synthesizeAttributes")
-    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
+    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return jsii.invoke(self, "synthesizeAttributes", [])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="id")
-    def id(self) -> typing.Optional[str]:
+    def id(self) -> typing.Optional[builtins.str]:
         return jsii.get(self, "id")
 
-    @id.setter
-    def id(self, value: typing.Optional[str]) -> None:
+    @id.setter # type: ignore
+    def id(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "id", value)
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="triggers")
-    def triggers(self) -> typing.Optional[typing.Mapping[str, str]]:
+    def triggers(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         return jsii.get(self, "triggers")
 
-    @triggers.setter
-    def triggers(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
+    @triggers.setter # type: ignore
+    def triggers(
+        self,
+        value: typing.Optional[typing.Mapping[builtins.str, builtins.str]],
+    ) -> None:
         jsii.set(self, "triggers", value)
 
 
@@ -381,7 +394,7 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
         depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
         lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
         provider: typing.Optional[cdktf.TerraformProvider] = None,
-        triggers: typing.Optional[typing.Mapping[str, str]] = None,
+        triggers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
     ) -> None:
         """
         :param count: 
@@ -392,7 +405,7 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
         """
         if isinstance(lifecycle, dict):
             lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if count is not None:
             self._values["count"] = count
         if depends_on is not None:
@@ -410,7 +423,8 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
         stability
         :stability: experimental
         """
-        return self._values.get("count")
+        result = self._values.get("count")
+        return result
 
     @builtins.property
     def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
@@ -418,7 +432,8 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
         stability
         :stability: experimental
         """
-        return self._values.get("depends_on")
+        result = self._values.get("depends_on")
+        return result
 
     @builtins.property
     def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
@@ -426,7 +441,8 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
         stability
         :stability: experimental
         """
-        return self._values.get("lifecycle")
+        result = self._values.get("lifecycle")
+        return result
 
     @builtins.property
     def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
@@ -434,16 +450,18 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
         stability
         :stability: experimental
         """
-        return self._values.get("provider")
+        result = self._values.get("provider")
+        return result
 
     @builtins.property
-    def triggers(self) -> typing.Optional[typing.Mapping[str, str]]:
-        return self._values.get("triggers")
+    def triggers(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
+        result = self._values.get("triggers")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
